#
# spec file for package ghc-pandoc-citeproc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name pandoc-citeproc
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.14.3.1
Release:        1.2
Summary:        Supports using pandoc with citeproc
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-pretty-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-hs-bibutils-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-old-locale-devel
BuildRequires:  ghc-pandoc-devel
BuildRequires:  ghc-pandoc-types-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-rfc5051-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-setenv-devel
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-syb-devel
BuildRequires:  ghc-tagsoup-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-xml-conduit-devel
BuildRequires:  ghc-yaml-devel
%if %{with tests}
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-temporary-devel
%endif

%description
The pandoc-citeproc library exports functions for using the citeproc system
with pandoc. It relies on citeproc-hs, a library for rendering bibliographic
reference citations into a variety of styles using a macro language called
Citation Style Language (CSL). More details on CSL can be found here:
<http://citationstyles.org/>.

Currently this package includes a heavily revised copy of the citeproc-hs code.
When citeproc-hs is updated to be compatible, this package will simply depend
on citeproc-hs.

This package also contains an executable: pandoc-citeproc, which works as a
pandoc filter, and also has a mode for converting bibliographic databases a
YAML format suitable for inclusion in pandoc YAML metadata.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%{_bindir}/%{pkg_name}
%dir %{_datadir}/%{pkg_name}-%{version}
%dir %{_datadir}/%{pkg_name}-%{version}/locales
%dir %{_datadir}/%{pkg_name}-%{version}/man
%dir %{_datadir}/%{pkg_name}-%{version}/man/man1
%{_datadir}/%{pkg_name}-%{version}/LICENSE
%{_datadir}/%{pkg_name}-%{version}/README.md
%{_datadir}/%{pkg_name}-%{version}/changelog
%{_datadir}/%{pkg_name}-%{version}/chicago-author-date.csl
%{_datadir}/%{pkg_name}-%{version}/locales/*.xml
%{_datadir}/%{pkg_name}-%{version}/man/man1/pandoc-citeproc.1

%files devel -f %{name}-devel.files

%{_mandir}/man1/pandoc-citeproc.1%{?ext_man}

%changelog
* Tue May  1 2018 psimons@suse.com
- Update pandoc-citeproc to version 0.14.3.1.
  A more detailed change log is not available.
* Thu Apr 12 2018 psimons@suse.com
- Update pandoc-citeproc to version 0.14.3.
  A more detailed change log is not available.
* Mon Aug 14 2017 psimons@suse.com
- Update to version 0.10.5.1 revision 1.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 0.10.5.1.
* Mon Apr 24 2017 psimons@suse.com
- Update to version 0.10.4.1 revision 1 with cabal2obs.
* Mon Feb 20 2017 psimons@suse.com
- Update to version 0.10.4.1 with cabal2obs.
* Mon Jan 30 2017 psimons@suse.com
- Update to version 0.10.4 with cabal2obs.
* Wed Jan  4 2017 psimons@suse.com
- Update to version 0.10.3 revision 1 with cabal2obs.
* Sun Dec  4 2016 psimons@suse.com
- Update to version 0.10.3 with cabal2obs.
* Sun Oct 30 2016 psimons@suse.com
- Update to version 0.10.2.2 with cabal2obs.
* Mon Oct 17 2016 psimons@suse.com
- Update to version 0.10.1.2 with cabal2obs.
* Mon Sep 26 2016 psimons@suse.com
- Update to version 0.10.1.1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.10.1 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.9.1.1 revision 0 with cabal2obs.
